import graphene
import graphene_django

from graphene import relay, ObjectType
from graphene_django import DjangoObjectType
from graphene_django.filter import DjangoFilterConnectionField
from .models import Datos_personales, Estudios, Antecedentes, Autoevaluacion_salud, Percepcion, Personalidad, Estatus_economico, Nutricion, Actividad_fisica, Informacion_salud, Observaciones, Antropometria, Laboratorio, Bioimpedancia

class Datos_personalesNode(DjangoObjectType):
	class Meta:
		model = Datos_personales
		
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'fecha_encuesta': ['exact'],
			'cuenta': ['exact','icontains','istartswith'],
			'estado': ['exact','icontains','istartswith'],
			'codigo_postal': ['exact','icontains','istartswith'],
			'sexo': ['exact'],
			'estado_civil':['exact','icontains','istartswith']
			}
		
		interfaces = (relay.Node, )

class EstudiosNode(DjangoObjectType):
	class Meta:
		
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'grado_estudios':['exact'],
			'grado_estudios_madre':['exact'],
			'grado_estudios_padre':['exact'],
			'promedio_academico': ['exact','lte','gte','lt','gt'],
			'horas_lectivas_diarias':['exact'], 
			'horas_recreativas_diarias':['exact'], 
			'horas_diarias_transporte':['exact'], 
			'tipo_transporte_facmed':['exact']
			}
		model = Estudios
		interfaces = (relay.Node, )

class AntecedentesNode(DjangoObjectType):
	class Meta:
		
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'tienes_sobrepeso':['exact'], 
			'edad_dx_sobrepeso':['exact','lte','gte','lt','gt'],
			'tienes_obesidad':['exact'], 
			'edad_dx_obesidad':['exact','lte','gte','lt','gt'], 
			'padeces_enfermedades_cronicas':['exact'],
			'edad_dx_enfermedades_cronicas':['exact','lte','gte','lt','gt'],
			'padre_padece_enfermedades_cronicas':['exact'],
			'edad_dx_padre_enfermedades_cronicas':['exact','lte','gte','lt','gt'],
			'madre_padece_enfermedades_cronicas':['exact'],
			'edad_dx_madre_enfermedades_cronicas':['exact','lte','gte','lt','gt'],
			'padres_vivos':['exact'],
			'padre_vivo_edad':['exact','lte','gte','lt','gt'],
			'padre_muerto_edad':['exact','lte','gte','lt','gt'],
			'madre_viva_edad':['exact','lte','gte','lt','gt'],
			'madre_muerta_edad':['exact','lte','gte','lt','gt'],
			'padre_vivo_sp_obesidad_dm_cardio':['exact'],
			'madre_viva_sp_obesidad_dm_crdio':['exact'],
			'hermanos_tienes':['exact','lte','gte','lt','gt'],
			'primer_hermano_vivo_muerto':['exact'],
			'primer_hermano_edad':['exact','lte','gte','lt','gt'],
			'primer_hermano_sp_obesidad_dm_cardio':['exact'],
			'segundo_hermano_vivo_muerto':['exact'],
			'segundo_hermano_edad':['exact','lte','gte','lt','gt'],
			'segundo_hermano_sp_obesidad_dm_cardio':['exact'],
			'tercer_hermano_vivo_muerto':['exact'],
			'tercer_hermano_edad':['exact','lte','gte','lt','gt'],
			'tercer_hermano_sp_obesidad_dm_cardio':['exact'],
			'cuarto_hermano_vivo_muerto':['exact'],
			'cuarto_hermano_edad':['exact','lte','gte','lt','gt'],
			'cuarto_hermano_sp_obesidad_dm_cardio':['exact'],
			'hijos_tienes':['exact','lte','gte','lt','gt'],
			'primer_hijo_edad':['exact','lte','gte','lt','gt'],
			'primer_hijo_sp_obesidad_dm':['exact'],
			'primer_hijo_peso_nacer':['exact','lte','gte','lt','gt'],
			'segundo_hijo_edad':['exact','lte','gte','lt','gt'],
			'segundo_hijo_sp_obesidad_dm':['exact'],
			'segundo_hijo_peso_nacer':['exact','lte','gte','lt','gt'],
			'tercer_hijo_edad':['exact','lte','gte','lt','gt'],
			'tercer_hijo_sp_obesidad_dm':['exact'],
			'tercer_hijo_peso_nacer':['exact','lte','gte','lt','gt'],
			'cuarto_hijo_edad':['exact','lte','gte','lt','gt'],
			'cuarto_hijo_sp_obesidad_dm':['exact'],
			'cuarto_hijo_peso_nacer':['exact','lte','gte','lt','gt'],
			'pareja_tienes':['exact'],
			'edad_pareja':['exact','lte','gte','lt','gt'],
			'pareja_sp_obesidad_dm':['exact'],
			'amigos_proporcion_sp_obesidad':['exact'],
			'amigos_cercanos_tienes':['exact','lte','gte','lt','gt']
			}

		model = Antecedentes		
		interfaces = (relay.Node, )
		
class Autoevaluacion_saludNode(DjangoObjectType):
	class Meta:
	
		filter_fields = {

			'id': ['exact','icontains','istartswith'],
			'peso_actual':['exact','lte','gte','lt','gt'],
			'pesaste_ultima_vez':['exact'],
			'estatura':['exact','lte','gte','lt','gt'],
			'consideras_peso_actual':['exact'],
			'consideras_peso_1':['exact'],
			'consideras_peso_5':['exact'],
			'acciones_respecto_peso':['exact'],
			'intento_bajar_subir_peso':['exact'],
			'estres_actual':['exact'],
			'estres_1':['exact'],
			'estres_5':['exact'],
			'condicion_fisica_actual':['exact'],
			'condicion_fisica_1':['exact'],
			'condicion_fisica_5':['exact'],
			'suenno_diario':['exact','lte','gte','lt','gt'],
			'suenno_calidad':['exact','lte','gte','lt','gt'],
			'suenno_diario_1ano':['exact','lte','gte','lt','gt'],
			'suenno_diario_5anos' :['exact','lte','gte','lt','gt'],
			'salud_actual':['exact'],
			'salud_actual_1ano':['exact'],
			'salud_actual_5anos':['exact'],
			'trastorno_sueno':['exact'],
			'alcohol_semana':['exact'],
			'tipo_bebida_alcoholica':['exact'],
			'edad_tomando':['exact'] 
			}
		
		model = Autoevaluacion_salud
		interfaces = (relay.Node, )

class PercepcionNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'stuntkard_peso_actual':['exact','lte','gte','lt','gt'],
			'stuntkard_figura_ideal':['exact','lte','gte','lt','gt'],
			'stuntkard_peso_1ano':['exact','lte','gte','lt','gt'],
			'stuntkard_peso_5anos':['exact','lte','gte','lt','gt']
			}
		model = Percepcion
		interfaces = (relay.Node, )

class PersonalidadNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'soy_organizado':['exact'],
			'soy_responsable':['exact'] ,
			'soy_dedicado':['exact'] ,
			'soy_descuidado':['exact'] ,
			'soy_minucioso':['exact'] ,
			'soy_disciplinado':['exact'] ,
			'planear_futuro':['exact'] ,
			'buena_suerte':['exact'] ,
			'propios_exitos':['exact'] ,
			'cualquier_cosa_propuesta':['exact'] ,
			'problemas_mala_suerte':['exact'] ,
			'control_malos_sucesos':['exact'] ,
			'desgracias_errores':['exact'] ,
			'responsable_fallas' :['exact'] 
			}
		model = Personalidad
		interfaces = (relay.Node, )
		
class Estatus_economicoNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'actividad_remunerada':['exact'] ,
			'horas_semana_actividad':['exact'], 
			'ingreso_mensual':['exact'] ,
			'gastos_personales_mensuales':['exact'] ,
			'vives_padres_familia':['exact'] ,
			'focos_vivienda':['exact'] ,
			'focos_vivienda_rentada':['exact'] ,
			'personas_compartes_dormitorio_familia':['exact'] ,
			'personas_compartes_dormitorio_rentas':['exact']  
			}
		model = Estatus_economico
		interfaces = (relay.Node, )

class NutricionNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'comidas_fuertes':['exact'] ,
			'calorias_crees_recomendadas':['exact'] ,
			'comes_relativo_recomendado':['exact'],
			'numero_refrescos_normales_consumes':['exact'] ,
			'numero_cereales_tuberculos_consumes':['exact'] ,
			'numero_frutas_consumes':['exact'] ,
			'numero_maiz_consumes':['exact'] ,
			'numero_tortillas_consumes':['exact'] ,
			'numero_carne_etc_consumes':['exact'] ,
			'numero_verduras_leguminosas_consumes':['exact'] ,
			'numero_botanas_etc_consumes':['exact'] ,
			'numero_comes_fuera_casa':['exact'] ,
			'numero_cfca':['exact'] ,
			'numero_cfcc':['exact'] 
			}
		model = Nutricion
		interfaces = (relay.Node, )

class Actividad_fisicaNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'horas_ejercicio_actual':['exact','lte','gte','lt','gt'],
			'horas_ejercicio_1ano':['exact','lte','gte','lt','gt'],
			'horas_ejercicio_5ano':['exact','lte','gte','lt','gt'],
			'tipo_ejercicio_actual':['exact'] ,
			'tipo_ejercicio_1ano':['exact'] ,
			'tipo_ejercicio_5anos':['exact'] ,
			'donde_haces_ejercicio':['exact'] ,
			'gusta_ejercicio_intenso':['exact'] ,
			'r_medicas':['exact'] 
			}
		model = Actividad_fisica
		interfaces = (relay.Node, )

class Informacion_saludNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'imc_normal':['exact'],
			'stuntkard_bajo_peso':['exact','lte','gte','lt','gt'],
			'stuntkard_normal_peso':['exact','lte','gte','lt','gt'],
			'stuntkard_sobrepeso':['exact','lte','gte','lt','gt'],
			'stuntkard_obeso':['exact','lte','gte','lt','gt'],
			'porc_mexicanos_obesidad':['exact'],
			'calorias_refresco':['exact'],
			'calorias_agua':['exact'],
			'calorias_manzana':['exact'],
			'distancia_calorias_coca':['exact'],
			'cambio_habitos_probabilidad_dm':['exact'],
			'factores_obesidad_dm':['exact'],
			'eres_religioso':['exact'],
			'partidario_politico':['exact'],
			'cual_partido_politico':['exact'] 
			}
		model = Informacion_salud
		interfaces = (relay.Node, )

class ObservacionesNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'observaciones':['exact'],
			'etiquetas':['exact'] 
			}
		model = Observaciones
		interfaces = (relay.Node, )

class AntropometriaNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'peso_real':['exact'],
			'talla_real':['exact'],
			'presion_sistolica':['exact'],
			'presion_diastolica':['exact'],
			'circunferencia_brazo':['exact'],
			'circunferencia_cintura':['exact'],
			'circunferencia_cadera':['exact'],
			'temperatura_axilar':['exact'],
			'temperatura_oido':['exact'],
			'temperatura_muneca':['exact'],
			'bioimpedancia_peso':['exact'],
			'bioimpedancia_porcentaje_grasa':['exact'],
			'bioimpedancia_porcentaje_agua':['exact'],
			'plicometria_triceps':['exact'],
			'plicometria_biceps':['exact'],
			'plicometria_suprailiaco':['exact'],
			'plicometria_subescapular':['exact'] 
			}
		model = Antropometria
		interfaces = (relay.Node, )

class LaboratorioNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'paciente':['exact'],
			'glucosa':['exact'],
			'urea':['exact'],
			'creatinina':['exact'],
			'acido_urico':['exact'],
			'colesterol_total':['exact'],
			'trigliceridos':['exact'],
			'bilirrubina_total':['exact'],
			'bilirrubina_directa':['exact'],
			'bilirrubina_indirecta':['exact'],
			'aspartato_amino_transferasa':['exact'],
			'calcio':['exact'],
			'fosforo':['exact'],
			'hemoglobina_glucosilada':['exact'],
			'glucosa_promedio_estimada':['exact'],
			'insulina_basal':['exact'],
			'hemoglobina':['exact'],
			'hematocrito':['exact'],
			'eritrocitos':['exact'],
			'vgm':['exact'],
			'hgm':['exact'],
			'chcm':['exact'],
			'rdw':['exact'],
			'leucocitos':['exact'],
			'porcentaje_neutrofilos_totales':['exact'],
			'porcentaje_neutrofilos_segmentados':['exact'],
			'porcentaje_neutrofilos_en_banda':['exact'],
			'numero_eosinofilos':['exact'],
			'porcentaje_eosinofilos':['exact'],
			'numero_basofilos':['exact'],
			'porcentaje_basofilos':['exact'],
			'numero_linfocitos':['exact'],
			'porcentaje_linfocitos':['exact'],
			'numero_monocitos':['exact'],
			'porcentaje_monocitos':['exact'],
			'plaquetas':['exact'],
			'vpm':['exact'],
			'paciente':['exact'],
			'glucosa':['exact'],
			'urea':['exact'],
			'creatinina':['exact'],
			'acido_urico':['exact'],
			'colesterol_total':['exact'],
			'trigliceridos':['exact'],
			'hemoglobina_glucosilada':['exact'],
			'insulina_basal':['exact'],
			'hemoglobina':['exact'],
			'hematocrito':['exact'],
			'eritrocitos':['exact'],
			'vgm':['exact'],
			'chcm':['exact'],
			'leucocitos':['exact'],
			'porcentaje_neutrofilos_totales':['exact'],
			'porcentaje_eosinofilos':['exact'],
			'porcentaje_basofilos':['exact'],
			'porcentaje_linfocitos':['exact'],
			'porcentaje_monocitos':['exact'],
			'plaquetas':['exact'],
			'hdl':['exact'],
			'ldl':['exact'],
			'bun':['exact'],
			'albumina':['exact'],
			'pcr':['exact'],
			'cloro':['exact'],
			'potasio':['exact'],
			'sodio':['exact'],
			'glucosa':['exact'],
			'colesterol_total':['exact'],
			'hemoglobina_glucosilada':['exact'],
			'insulina_basal':['exact'],
			'hdl':['exact'],
			'ldl':['exact'],
			'bun':['exact'],
			'pcr':['exact'] 
			}
		model = Laboratorio
		interfaces = (relay.Node, )

class BioimpedanciaNode(DjangoObjectType):
	class Meta:
		filter_fields = {
			'id': ['exact','icontains','istartswith'],
			'edad_real':['exact'],
			'munneca':['exact'],
			'porc_musculos':['exact'],
			'rmkcal':['exact'],
			'edad_corporal':['exact'],
			'imc':['exact'],
			'grasa_visceral':['exact'] 
			}
		model = Bioimpedancia
		interfaces = (relay.Node, )

class Query(graphene.ObjectType):
	
	datos = relay.Node.Field(Datos_personalesNode)
	all_datos = DjangoFilterConnectionField(Datos_personalesNode)

	estudios = relay.Node.Field(EstudiosNode)
	all_estudios = DjangoFilterConnectionField(EstudiosNode)
	
	antecedentes = relay.Node.Field(AntecedentesNode)
	all_antecedentes = DjangoFilterConnectionField(AntecedentesNode)

	autoevaluacion = relay.Node.Field(Autoevaluacion_saludNode)
	all_autoevaluacion = DjangoFilterConnectionField(Autoevaluacion_saludNode)

	percepcion = relay.Node.Field(PercepcionNode)
	all_percepcion = DjangoFilterConnectionField(PercepcionNode)

	personalidad = relay.Node.Field(PersonalidadNode)
	all_personalidad = DjangoFilterConnectionField(PersonalidadNode)

	estatus = relay.Node.Field(Estatus_economicoNode)
	all_estatus = DjangoFilterConnectionField(Estatus_economicoNode)

	nutricion = relay.Node.Field(NutricionNode)
	all_nutricion = DjangoFilterConnectionField(NutricionNode)

	actividad = relay.Node.Field(Actividad_fisicaNode)
	all_actividad = DjangoFilterConnectionField(Actividad_fisicaNode)

	informacion = relay.Node.Field(Informacion_saludNode)
	all_informacion = DjangoFilterConnectionField(Informacion_saludNode)

	observaciones = relay.Node.Field(ObservacionesNode)
	all_observaciones = DjangoFilterConnectionField(ObservacionesNode)

	antropometria = relay.Node.Field(AntropometriaNode)
	all_antropometria = DjangoFilterConnectionField(AntropometriaNode)

	laboratorio = relay.Node.Field(LaboratorioNode)
	all_laboratorio = DjangoFilterConnectionField(LaboratorioNode)

	bioimpedancia = relay.Node.Field(BioimpedanciaNode)
	all_bioimpedancia = DjangoFilterConnectionField(BioimpedanciaNode)

schema = graphene.Schema(query=Query)
